#[non_exhaustive]pub enum Request {
GetShellSurface {
id: New<WlShellSurface>,
surface: WlSurface,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GetShellSurface
create a shell surface from a surface
Create a shell surface for an existing surface. This gives the wl_surface the role of a shell surface. If the wl_surface already has another role, it raises a protocol error.
Only one shell surface can be associated with a given surface.
Fields

id: New<WlShellSurface>shell surface to create
Implementations