pub struct WlShell { /* private fields */ }Expand description
create desktop-style surfaces
This interface is implemented by servers that provide desktop-style user interfaces.
It allows clients to associate a wl_shell_surface with a basic surface.
Note! This protocol is deprecated and not intended for production use. For desktop-style user interfaces, use xdg_shell. Compositors and clients should not implement this interface.
See also the Request enum for this interface.